package com.chelvc.framework.database.interceptor;

import com.baomidou.mybatisplus.core.metadata.TableInfo;
import com.baomidou.mybatisplus.extension.plugins.handler.TenantLineHandler;
import com.chelvc.framework.database.context.DatabaseContextHolder;
import com.chelvc.framework.database.entity.Deletable;
import net.sf.jsqlparser.expression.Expression;

/**
 * 借助租户隔离功能实现删除数据排除拦截，数据查询自动过滤已删除数据
 *
 * @author Woody
 * @date 2024/1/30
 */
public class DeletedExcludeInterceptor implements TenantLineHandler {
    @Override
    public Expression getTenantId() {
        return Expressions.ZERO_VALUE;
    }

    @Override
    public String getTenantIdColumn() {
        return Expressions.DELETED_COLUMN.getColumnName();
    }

    @Override
    public boolean ignoreTable(String tableName) {
        TableInfo table = DatabaseContextHolder.getTable(tableName);
        return table == null || !Deletable.class.isAssignableFrom(table.getEntityType());
    }
}
