package com.chelvc.framework.database.listener;

import java.util.Collection;

import com.chelvc.framework.common.util.ObjectUtils;


/**
 * 数据删除操作监听器接口
 *
 * @param <T> 数据类型
 * @author Woody
 * @date 2024/4/30
 */
public interface DeleteListener<T> extends OperateListener<T> {
    /**
     * 监听数据删除
     *
     * @param entity 对象实例
     */
    default void delete(T entity) {
    }

    /**
     * 监听数据批量删除
     *
     * @param entities 对象实例集合
     */
    default void delete(Collection<T> entities) {
        if (ObjectUtils.notEmpty(entities)) {
            entities.forEach(this::delete);
        }
    }
}
