package com.chelvc.framework.database.listener;

import java.util.Collection;

import com.chelvc.framework.common.util.ObjectUtils;
import org.apache.commons.lang3.tuple.Pair;

/**
 * 数据更新操作监听器接口
 *
 * @param <T> 数据类型
 * @author Woody
 * @date 2024/4/30
 */
public interface ModifyListener<T> extends OperateListener<T> {
    /**
     * 监听数据更新
     *
     * @param before 更新前对象实例
     * @param after  更新后对象实例
     */
    default void modify(T before, T after) {
    }

    /**
     * 监听数据批量更新
     *
     * @param pairs 更新前后对象实例集合
     */
    default void modify(Collection<Pair<T, T>> pairs) {
        if (ObjectUtils.notEmpty(pairs)) {
            pairs.forEach(pair -> this.modify(pair.getLeft(), pair.getRight()));
        }
    }
}
