package com.chelvc.framework.database.support;

import java.util.List;

import com.baomidou.mybatisplus.core.metadata.TableFieldInfo;
import com.baomidou.mybatisplus.core.metadata.TableInfo;
import lombok.NonNull;

/**
 * 批量创建或修改方法实现
 *
 * @author Woody
 * @date 2024/2/27
 */
public class BatchCreateUpdateMethod extends AbstractCreateMethod {
    public BatchCreateUpdateMethod() {
        super("batchCreateUpdate");
    }

    @Override
    protected String initializeMethodScript(@NonNull TableInfo table) {
        List<TableFieldInfo> fields = table.getFieldList();
        String columns = this.field2column(table, fields);
        String properties = this.field2property(table, "entity.", fields);
        String updates = "<foreach collection=\"update.expressions.entrySet()\" " +
                "index=\"column\" item=\"value\" separator=\",\">${column}${value}</foreach>";
        return String.format(
                "<script>\nINSERT INTO %s (%s) VALUES\n" +
                        "<foreach collection=\"entities\" item=\"entity\" separator=\",\">(%s)</foreach>\n" +
                        "ON DUPLICATE KEY UPDATE %s\n</script>",
                table.getTableName(), columns, properties, updates
        );
    }
}
