package com.chelvc.framework.feign.interceptor;

import com.chelvc.framework.base.context.ApplicationContextHolder;
import com.chelvc.framework.base.context.Session;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.base.util.HttpUtils;
import com.chelvc.framework.common.model.Platform;
import com.chelvc.framework.common.model.Terminal;
import com.chelvc.framework.common.util.ObjectUtils;
import feign.RequestInterceptor;
import feign.RequestTemplate;

/**
 * Feign调用处理拦截器
 *
 * @author Woody
 * @date 2024/1/30
 */
public class FeignInvokeInterceptor implements RequestInterceptor {
    /**
     * 初始化请求前缀
     *
     * @param template 请求模版对象实例
     */
    protected void initializeRequestPrefix(RequestTemplate template) {
        String path = template.path();
        String server = template.feignTarget().name();
        if (ApplicationContextHolder.isResourcePrefixed(server, path)) {
            template.uri(HttpUtils.uri(server, path));
        }
    }

    /**
     * 初始化请求头
     *
     * @param template 请求模版对象实例
     */
    protected void initializeRequestHeader(RequestTemplate template) {
        Session session = SessionContextHolder.getSession(false);
        if (session != null) {
            template.header("x-real-ip", session.getHost());
            template.header(SessionContextHolder.HEADER_ID,
                    (String) ObjectUtils.ifNull(session.getId(), String::valueOf));
            template.header(SessionContextHolder.HEADER_SCOPE, session.getScope());
            template.header(SessionContextHolder.HEADER_DEVICE, session.getDevice());
            template.header(SessionContextHolder.HEADER_CHANNEL, session.getChannel());
            template.header(SessionContextHolder.HEADER_PLATFORM,
                    ObjectUtils.ifNull(session.getPlatform(), Platform::name));
            template.header(SessionContextHolder.HEADER_TERMINAL,
                    ObjectUtils.ifNull(session.getTerminal(), Terminal::name));
            template.header(SessionContextHolder.HEADER_VERSION, session.getVersion());
            template.header(SessionContextHolder.HEADER_FINGERPRINT, session.getFingerprint());
            template.header(SessionContextHolder.HEADER_ANONYMOUS, String.valueOf(session.isAnonymous()));
            template.header(SessionContextHolder.HEADER_TIMESTAMP,
                    (String) ObjectUtils.ifNull(session.getTimestamp(), String::valueOf));
        }
    }

    @Override
    public void apply(RequestTemplate template) {
        this.initializeRequestPrefix(template);
        this.initializeRequestHeader(template);
    }
}
